{{ fullname | escape | underline}}


.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :members:

   {% block methods %}

   {% if methods %}
   .. rubric:: {{ _('Methods') }}

   .. autosummary::
   {% for item in methods %}
       {% if not (item.startswith('__') and item.endswith('__')) %}
          ~{{ name }}.{{ item }}
       {%- endif %}
   {%- endfor %}
   {% endif %}
   {% endblock %}

   {% block attributes %}
   {% if attributes %}
   .. rubric:: {{ _('Attributes') }}

   .. autosummary::
   {% for item in attributes %}
      ~{{ name }}.{{ item }}
   {%- endfor %}
   {% endif %}
   {% endblock %}

   {% block classes %}

   .. autosummary::
   {% for item in elements %}
       {% if item[0].isupper() %}
          ~{{ name }}.{{ item }}
       {%- endif %}
   {%- endfor %}
   {% endblock %}
